@@ -124,7 +124,7 @@ class QuerySet:
         return self.model_cls.registry.database
 
     @property
-    def table(self):
+    def table(self) -> sqlalchemy.Table:
         return self.model_cls.table
 
     @property
@@ -389,10 +389,9 @@ class QuerySet:
         )
         kwargs = validator.validate(kwargs)
 
-        # TODO: Better to implement after UUID, probably need another database
-        # for key, value in fields.items():
-        #     if value.validator.read_only and value.validator.has_default():
-        #         kwargs[key] = value.validator.get_default_value()
+        for key, value in fields.items():
+            if value.validator.read_only and value.validator.has_default():
+                kwargs[key] = value.validator.get_default_value()
 
         # Build the insert expression.
         expr = self.table.insert()
@@ -403,11 +402,49 @@ class QuerySet:
         instance.pk = await self.database.execute(expr)
         return instance
 
-    async def get_or_create(self, **kwargs) -> typing.Tuple[typing.Any, bool]:
+    async def delete(self) -> None:
+        expr = self.table.delete()
+        for filter_clause in self.filter_clauses:
+            expr = expr.where(filter_clause)
+
+        await self.database.execute(expr)
+
+    async def update(self, **kwargs) -> None:
+        fields = {
+            key: field.validator
+            for key, field in self.model_cls.fields.items()
+            if key in kwargs
+        }
+        validator = typesystem.Schema(fields=fields)
+        kwargs = validator.validate(kwargs)
+
+        expr = self.table.update().values(**kwargs)
+
+        for filter_clause in self.filter_clauses:
+            expr = expr.where(filter_clause)
+
+        await self.database.execute(expr)
+
+    async def get_or_create(
+        self, defaults: typing.Dict[str, typing.Any], **kwargs
+    ) -> typing.Tuple[typing.Any, bool]:
         try:
             instance = await self.get(**kwargs)
             return instance, False
         except NoMatch:
+            kwargs.update(defaults)
+            instance = await self.create(**kwargs)
+            return instance, True
+
+    async def update_or_create(
+        self, defaults: typing.Dict[str, typing.Any], **kwargs
+    ) -> typing.Tuple[typing.Any, bool]:
+        try:
+            instance = await self.get(**kwargs)
+            await instance.update(**defaults)
+            return instance, False
+        except NoMatch:
+            kwargs.update(defaults)
             instance = await self.create(**kwargs)
             return instance, True
 
@@ -449,35 +486,29 @@ class Model(metaclass=ModelMeta):
         return sqlalchemy.Table(tablename, metadata, *columns, extend_existing=True)
 
     @property
-    def table(self):
+    def table(self) -> sqlalchemy.Table:
         return self.__class__.table
 
     async def update(self, **kwargs):
-        # Validate the keyword arguments.
         fields = {
             key: field.validator for key, field in self.fields.items() if key in kwargs
         }
         validator = typesystem.Schema(fields=fields)
         kwargs = validator.validate(kwargs)
 
-        # Build the update expression.
         pk_column = getattr(self.table.c, self.pkname)
-        expr = self.table.update()
-        expr = expr.values(**kwargs).where(pk_column == self.pk)
+        expr = self.table.update().values(**kwargs).where(pk_column == self.pk)
 
-        # Perform the update.
         await self.database.execute(expr)
 
         # Update the model instance.
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-    async def delete(self):
-        # Build the delete expression.
+    async def delete(self) -> None:
         pk_column = getattr(self.table.c, self.pkname)
         expr = self.table.delete().where(pk_column == self.pk)
 
-        # Perform the delete.
         await self.database.execute(expr)
 
     async def load(self):
